@@ -4,6 +4,10 @@ package Module::Install::WriteAll;
 use Module::Install::Base;
 @ISA = qw(Module::Install::Base);
 
+$VERSION = '0.59';
+
+use strict;
+
 sub WriteAll {
     my $self = shift;
     my %args = (
@@ -14,22 +18,20 @@ sub WriteAll {
         @_
     );
 
-    $self->sign(1) if $args{sign};
-    $self->Meta->write if $args{meta};
+    $self->sign(1)                if $args{sign};
+    $self->Meta->write            if $args{meta};
     $self->admin->WriteAll(%args) if $self->is_admin;
 
-    if ($0 =~ /Build.PL$/i) {
+    if ( $0 =~ /Build.PL$/i ) {
         $self->Build->write;
-    }
-    else {
+    } else {
         $self->check_nmake if $args{check_nmake};
-        $self->makemaker_args( PL_FILES => {} )
-            unless $self->makemaker_args->{'PL_FILES'};
-
+        unless ( $self->makemaker_args->{'PL_FILES'} ) {
+        	$self->makemaker_args( PL_FILES => {} );
+        }
         if ($args{inline}) {
             $self->Inline->write;
-        }
-        else {
+        } else {
             $self->Makefile->write;
         }
     }
